@@ -1,12 +1,22 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2017 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -17,8 +27,8 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
-**     of its contributors may be used to endorse or promote products derived
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
 **     from this software without specific prior written permission.
 **
 **
@@ -38,15 +48,43 @@
 **
 ****************************************************************************/
 
-#include <QtUiTools>
-#include <QtWidgets>
 #include "textfinder.h"
+#include <QFile>
+#include <QLineEdit>
+#include <QMessageBox>
+#include <QPushButton>
+#include <QTextEdit>
+#include <QTextStream>
+#include <QUiLoader>
+#include <QVBoxLayout>
+
+//! [4]
+static QWidget *loadUiFile(QWidget *parent)
+{
+    QFile file(":/forms/textfinder.ui");
+    file.open(QIODevice::ReadOnly);
+
+    QUiLoader loader;
+    return loader.load(&file, parent);
+}
+//! [4]
+
+//! [5]
+static QString loadTextFile()
+{
+    QFile inputFile(":/forms/input.txt");
+    inputFile.open(QIODevice::ReadOnly);
+    QTextStream in(&inputFile);
+    in.setCodec("UTF-8");
+    return in.readAll();
+}
+//! [5]
 
 //! [0]
 TextFinder::TextFinder(QWidget *parent)
     : QWidget(parent)
 {
-    QWidget *formWidget = loadUiFile();
+    QWidget *formWidget = loadUiFile(this);
 
 //! [1]
     ui_findButton = findChild<QPushButton*>("findButton");
@@ -59,7 +97,7 @@ TextFinder::TextFinder(QWidget *parent)
 //! [2]
 
 //! [3a]
-    loadTextFile();
+    ui_textEdit->setText(loadTextFile());
 //! [3a]
 
 //! [3b]
@@ -70,40 +108,9 @@ TextFinder::TextFinder(QWidget *parent)
 
 //! [3c]
     setWindowTitle(tr("Text Finder"));
-    isFirstTime = true;
 }
 //! [3c]
 
-//! [4]
-QWidget* TextFinder::loadUiFile()
-{
-    QUiLoader loader;
-
-    QFile file(":/forms/textfinder.ui");
-    file.open(QFile::ReadOnly);
-
-    QWidget *formWidget = loader.load(&file, this);
-    file.close();
-
-    return formWidget;
-}
-//! [4]
-
-//! [5]
-void TextFinder::loadTextFile()
-{
-    QFile inputFile(":/forms/input.txt");
-    inputFile.open(QIODevice::ReadOnly);
-    QTextStream in(&inputFile);
-    QString line = in.readAll();
-    inputFile.close();
-
-    ui_textEdit->append(line);
-    ui_textEdit->setUndoRedoEnabled(false);
-    ui_textEdit->setUndoRedoEnabled(true);
-}
-//! [5]
-
 //! [6] //! [7]
 void TextFinder::on_findButton_clicked()
 {
@@ -112,17 +119,17 @@ void TextFinder::on_findButton_clicked()
 
     bool found = false;
 
-    if (isFirstTime == false)
-        document->undo();
+    // undo previous change (if any)
+    document->undo();
 
     if (searchString.isEmpty()) {
         QMessageBox::information(this, tr("Empty Search Field"),
-                "The search field is empty. Please enter a word and click Find.");
+                                 tr("The search field is empty. "
+                                    "Please enter a word and click Find."));
     } else {
-
-        QTextCursor highlightCursor(document);  
+        QTextCursor highlightCursor(document);
         QTextCursor cursor(document);
-        
+
         cursor.beginEditBlock();
 //! [6]
 
@@ -131,12 +138,13 @@ void TextFinder::on_findButton_clicked()
         colorFormat.setForeground(Qt::red);
 
         while (!highlightCursor.isNull() && !highlightCursor.atEnd()) {
-            highlightCursor = document->find(searchString, highlightCursor, QTextDocument::FindWholeWords);
+            highlightCursor = document->find(searchString, highlightCursor,
+                                             QTextDocument::FindWholeWords);
 
             if (!highlightCursor.isNull()) {
                 found = true;
                 highlightCursor.movePosition(QTextCursor::WordRight,
-                                       QTextCursor::KeepAnchor);
+                                             QTextCursor::KeepAnchor);
                 highlightCursor.mergeCharFormat(colorFormat);
             }
         }
@@ -144,12 +152,11 @@ void TextFinder::on_findButton_clicked()
 //! [8]
         cursor.endEditBlock();
 //! [7] //! [9]
-        isFirstTime = false;
 
         if (found == false) {
             QMessageBox::information(this, tr("Word Not Found"),
-                "Sorry, the word cannot be found.");
-        }    
+                                     tr("Sorry, the word cannot be found."));
+        }
     }
 }
 //! [8] //! [9]
