@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Assistant of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -50,6 +45,9 @@ class QHelpContentWidget;
 class QHelpIndexModel;
 class QHelpIndexWidget;
 class QHelpSearchEngine;
+class QHelpFilterEngine;
+class QHelpEngineCore;
+struct QHelpLink;
 
 enum {
     ShowHomePage = 0,
@@ -77,22 +75,17 @@ public:
     QHelpIndexWidget *indexWidget();
     bool setupData();
     const QStringList registeredDocumentations() const;
+    QString documentationFileName(const QString &namespaceName) const;
     const QString collectionFile() const;
     bool registerDocumentation(const QString &docFile);
     bool unregisterDocumentation(const QString &namespaceName);
-    bool addCustomFilter(const QString &filterName,
-                         const QStringList &attributes);
-    bool removeCustomFilter(const QString &filterName);
-    void setCurrentFilter(const QString &filterName);
-    const QString currentFilter() const;
-    const QStringList customFilters() const;
     QUrl findFile(const QUrl &url) const;
     QByteArray fileData(const QUrl &url) const;
-    QMap<QString, QUrl> linksForIdentifier(const QString &id) const;
-    const QStringList filterAttributes() const;
-    const QStringList filterAttributes(const QString &filterName) const;
+    QList<QHelpLink> documentsForIdentifier(const QString &id) const;
     QString error() const;
 
+    QHelpFilterEngine *filterEngine() const;
+
     /*
      * To be called after assistant has finished looking for new documentation.
      * This will mainly cause the search index to be updated, if necessary.
@@ -179,13 +172,13 @@ public:
     bool showTabs() const;
     void setShowTabs(bool show);
 
-    static const QString TrUnfiltered();
-
     bool fullTextSearchFallbackEnabled() const;
 
     const QByteArray topicChooserGeometry() const;
     void setTopicChooserGeometry(const QByteArray &geometry);
 
+    QHelpEngineCore *helpEngine() const;
+
 signals:
 
     // For asynchronous doc updates triggered by external actions.
@@ -193,12 +186,8 @@ signals:
     void documentationUpdated(const QString &namespaceName);
 
     // Forwarded from QHelpEngineCore.
-    void currentFilterChanged(const QString &currentFilter);
     void setupFinished();
 
-private slots:
-    void handleCurrentFilterChanged(const QString &filter);
-
 private:
     HelpEngineWrapper(const QString &collectionFile);
     ~HelpEngineWrapper();
