@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
 ** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
@@ -26,15 +26,15 @@
 **
 ****************************************************************************/
 
-#include <QtCore/QVector>
-#include <QtGui/QMouseEvent>
-#include <QtWidgets/QGridLayout>
-#include <QtWidgets/QLabel>
-#include <QtWidgets/QPushButton>
-#include <QtWidgets/QDialogButtonBox>
-#include <QtGui/QPainter>
-#include <QtGui/QPainterPath>
-#include <QtWidgets/QStyleOption>
+#include <QtCore/qvector.h>
+#include <QtGui/qevent.h>
+#include <QtWidgets/qgridlayout.h>
+#include <QtWidgets/qlabel.h>
+#include <QtWidgets/qpushbutton.h>
+#include <QtWidgets/qdialogbuttonbox.h>
+#include <QtGui/qpainter.h>
+#include <QtGui/qpainterpath.h>
+#include <QtWidgets/qstyleoption.h>
 #include "versiondialog.h"
 
 QT_BEGIN_NAMESPACE
@@ -43,26 +43,26 @@ class VersionLabel : public QLabel
 {
     Q_OBJECT
 public:
-    VersionLabel(QWidget *parent = 0);
+    VersionLabel(QWidget *parent = nullptr);
 
 signals:
     void triggered();
 
 protected:
-    void mousePressEvent(QMouseEvent *me);
-    void mouseMoveEvent(QMouseEvent *me);
-    void mouseReleaseEvent(QMouseEvent *me);
-    void paintEvent(QPaintEvent *pe);
+    void mousePressEvent(QMouseEvent *me) override;
+    void mouseMoveEvent(QMouseEvent *me) override;
+    void mouseReleaseEvent(QMouseEvent *me) override;
+    void paintEvent(QPaintEvent *pe) override;
 private:
     QVector<QPoint> hitPoints;
     QVector<QPoint> missPoints;
     QPainterPath m_path;
-    bool secondStage;
-    bool m_pushed;
+    bool secondStage = false;
+    bool m_pushed = false;
 };
 
 VersionLabel::VersionLabel(QWidget *parent)
-        : QLabel(parent), secondStage(false), m_pushed(false)
+        : QLabel(parent)
 {
     setPixmap(QPixmap(QStringLiteral(":/qt-project.org/designer/images/designer.png")));
     hitPoints.append(QPoint(56, 25));
@@ -100,14 +100,14 @@ void VersionLabel::mouseReleaseEvent(QMouseEvent *me)
         if (!secondStage) {
             m_path.lineTo(me->pos());
             bool gotIt = true;
-            foreach(const QPoint &pt, hitPoints) {
+            for (const QPoint &pt : qAsConst(hitPoints)) {
                 if (!m_path.contains(pt)) {
                     gotIt = false;
                     break;
                 }
             }
             if (gotIt) {
-                foreach(const QPoint &pt, missPoints) {
+                for (const QPoint &pt : qAsConst(missPoints)) {
                     if (m_path.contains(pt)) {
                         gotIt = false;
                         break;
@@ -160,7 +160,7 @@ VersionDialog::VersionDialog(QWidget *parent)
 
     lbl->setText(tr("%1"
                     "<br/>Copyright (C) %2 The Qt Company Ltd."
-                    ).arg(version, QStringLiteral("2016")));
+                    ).arg(version, QStringLiteral("2021")));
 
     lbl->setWordWrap(true);
     lbl->setOpenExternalLinks(true);
