@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Linguist of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -50,10 +45,6 @@
 
 QT_BEGIN_NAMESPACE
 
-class LU {
-    Q_DECLARE_TR_FUNCTIONS(LUpdate)
-};
-
 enum { Tok_Eof, Tok_class, Tok_return, Tok_tr,
        Tok_translate, Tok_Ident, Tok_Package,
        Tok_Comment, Tok_String, Tok_Colon, Tok_Dot,
@@ -113,11 +104,11 @@ std::ostream &yyMsg(int line = 0)
 static QChar getChar()
 {
     if (yyInPos >= yyInStr.size())
-        return EOF;
+      return QChar(EOF);
     QChar c = yyInStr[yyInPos++];
-    if (c.unicode() == '\n')
+    if (c == QLatin1Char('\n'))
         ++yyCurLineNo;
-    return c.unicode();
+    return c;
 }
 
 static int getToken()
@@ -129,7 +120,7 @@ static int getToken()
     yyComment.clear();
     yyString.clear();
 
-    while ( yyCh != EOF ) {
+    while (yyCh != QChar(EOF)) {
         yyLineNo = yyCurLineNo;
 
         if ( yyCh.isLetter() || yyCh.toLatin1() == '_' ) {
@@ -174,7 +165,7 @@ static int getToken()
                 if ( yyCh == QLatin1Char('/') ) {
                     do {
                         yyCh = getChar();
-                        if (yyCh == EOF)
+                        if (yyCh == QChar(EOF))
                             break;
                         yyComment.append(yyCh);
                     } while (yyCh != QLatin1Char('\n'));
@@ -186,7 +177,7 @@ static int getToken()
 
                     while ( !metAsterSlash ) {
                         yyCh = getChar();
-                        if ( yyCh == EOF ) {
+                        if (yyCh == QChar(EOF)) {
                             yyMsg() << qPrintable(LU::tr("Unterminated Java comment.\n"));
                             return Tok_Comment;
                         }
@@ -209,7 +200,7 @@ static int getToken()
             case '"':
                 yyCh = getChar();
 
-                while ( yyCh != EOF && yyCh != QLatin1Char('\n') && yyCh != QLatin1Char('"') ) {
+                while (yyCh != QChar(EOF) && yyCh != QLatin1Char('\n') && yyCh != QLatin1Char('"')) {
                     if ( yyCh == QLatin1Char('\\') ) {
                         yyCh = getChar();
                         if ( yyCh == QLatin1Char('u') ) {
@@ -262,7 +253,7 @@ static int getToken()
                     yyCh = getChar();
                 do {
                     yyCh = getChar();
-                } while ( yyCh != EOF && yyCh != QLatin1Char('\'') );
+                } while (yyCh != QChar(EOF) && yyCh != QLatin1Char('\''));
                 yyCh = getChar();
                 break;
             case '{':
